@@ -2,38 +2,42 @@
 """
 
 from apyscript.expression import expression_file_util
-from apyscript.html import html_util
+from apyscript.type import value_util
+from apyscript.type.int import Int
+from apyscript.type.number_value_interface import NumberValueInterface
 from apyscript.type.variable_name_interface import VariableNameInterface
 from apyscript.validation import number_validation
 
 
 class YInterface(VariableNameInterface):
 
-    _y: int = 0
+    _y: Int = Int(value=0)
 
     @property
-    def y(self) -> int:
+    def y(self) -> Int:
         """
         Get y position.
 
         Returns
         -------
-        y : int
+        y : Int
             Y position.
         """
-        return self._y
+        return value_util.get_copy(value=self._y)
 
     @y.setter
-    def y(self, value: int) -> None:
+    def y(self, value: Int) -> None:
         """
         Update y position.
 
         Parameters
         ----------
-        value : int
+        value : int or Int
             Y position value.
         """
-        number_validation.validate_integer(integer=value)
+        if not isinstance(value, NumberValueInterface):
+            number_validation.validate_integer(integer=value)
+            value = Int(value=value)
         self._y = value
         self._append_y_update_expression()
 
@@ -41,10 +45,10 @@ class YInterface(VariableNameInterface):
         """
         Append y position updating expression.
         """
+        value_str: str = value_util.get_value_str_for_expression(
+            value=self._y)
         expression: str = (
-            f'{self.variable_name}.y({self.y});'
+            f'{self.variable_name}.y({value_str});'
         )
-        expression = html_util.wrap_expression_by_script_tag(
-            expression=expression)
-        expression_file_util.append_expression(
+        expression_file_util.wrap_by_script_tag_and_append_expression(
             expression=expression)
